name = 'mmmbop'
packages = ['mmmbop']
version = '0.1.8'
description = 'View MBtiles on localhost'
author = 'Laurier Rochon'
author_email = 'l@pwd.io'
url = 'https://github.com/l-r/mmmbop'
download_url = 'https://github.com/l-r/mmmbop/tarball/{}'.format(version)
keywords = ['MBtiles']
classifiers = []
include_package_data = True
